Learn R Programming

noncompliance (version 0.2.2)

AllColTotalsH0_CONT: Finds all column totals for Compliers and Never Takers under the sharp null for Compliers.

Description

Finds all compatible column totals for Compliers and Never Takers under the sharp null for Compliers, based on an observed dataset.

Usage

AllColTotalsH0_CONT(n_y0x0z0.H0, n_y1x0z0.H0, n_y0x0z1.H0, n_y1x0z1.H0, n_y0x1z1.H0, n_y1x1z1.H0)

Arguments

n_y0x0z0.H0
Number of individuals with Y=0, X=0, Z=0.
n_y1x0z0.H0
Number of individuals with Y=1, X=0, Z=0.
n_y0x0z1.H0
Number of individuals with Y=0, X=0, Z=1.
n_y1x0z1.H0
Number of individuals with Y=1, X=0, Z=1.
n_y0x1z1.H0
Number of individuals with Y=0, X=1, Z=1.
n_y1x1z1.H0
Number of individuals with Y=1, X=1, Z=1.

Value

A data.table with all possible combinations of the column totals for Compliers and Never Takers under the sharp null for Compliers.

Examples

Run this code
AllColTotalsH0_CONT(158, 14, 52, 12, 23, 78)

Run the code above in your browser using DataLab