Learn R Programming

noncompliance (version 0.2.2)

AllPossiblyObsH0_CONT: Finite population sample space given an observed dataset.

Description

Sample space of all possibly observable datasets given an observed dataset, assuming only Compliers and Never Takers in the population.

Usage

AllPossiblyObsH0_CONT(n_y0x0z0, n_y1x0z0, n_y0x0z1, n_y1x0z1, n_y0x1z1, n_y1x1z1, findGLR = FALSE)

Arguments

n_y0x0z0
Number of individuals with Y=0, X=0, Z=0.
n_y1x0z0
Number of individuals with Y=1, X=0, Z=0.
n_y0x0z1
Number of individuals with Y=0, X=0, Z=1.
n_y1x0z1
Number of individuals with Y=1, X=0, Z=1.
n_y0x1z1
Number of individuals with Y=0, X=1, Z=1.
n_y1x1z1
Number of individuals with Y=1, X=1, Z=1.
findGLR
Whether or not to find the generalized likelihood ratio (GLR) test statistic for each possible observable dataset.

Value

All possibly observable datasets in a data.table format.

Examples

Run this code
AllPossiblyObsH0_CONT(16, 1, 5, 1, 2, 8)
AllPossiblyObsH0_CONT(16, 1, 5, 1, 2, 8, findGLR=TRUE)

Run the code above in your browser using DataLab