Learn R Programming

noncompliance (version 0.2.2)

FindMLE_CONT_H0_hypergeoR: Maximum Likelihood Estimate under the sharp null for Compliers.

Description

Find the maximum likelihood estimate of the 2 by 4 contingency table assuming only Compliers and Never Takers in the population, under the sharp null for Compliers and with the multivariate hypergeometric sampling distribution.

Usage

FindMLE_CONT_H0_hypergeoR(n_y0x0z0, n_y1x0z0, n_y0x0z1, n_y1x0z1, n_y0x1z1, n_y1x1z1)

Arguments

n_y0x0z0
Number of individuals with Y=0, X=0, Z=0.
n_y1x0z0
Number of individuals with Y=1, X=0, Z=0.
n_y0x0z1
Number of individuals with Y=0, X=0, Z=1.
n_y1x0z1
Number of individuals with Y=1, X=0, Z=1.
n_y0x1z1
Number of individuals with Y=0, X=1, Z=1.
n_y1x1z1
Number of individuals with Y=1, X=1, Z=1.

Value

The maximum likelihood under the sharp null for Compliers, and the corresponding (possibly non-unique) 2 by 4 contingency table.

Examples

Run this code
FindMLE_CONT_H0_hypergeoR(158, 14, 52, 12, 23, 78)

Run the code above in your browser using DataLab